@@ -40,7 +40,7 @@
 
 #define QT_FEATURE_qqnx_pps -1
 
-#define QT_FEATURE_renameat2 -1
+#define QT_FEATURE_renameat2 1
 
 #define QT_FEATURE_slog2 -1
 
